image

package
v0.0.0-...-5adc77d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Overview

Package image provides functions for validating confidential space images.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetGoldenValues

GetGoldenValues returns the golden values for the associated MachineState.

func KnownCertificate

KnownCertificate returns the *x509.Certificate for a given rimpb.ImageDatabase_CCKnownCertificates enum value.

func NormalizeCmdLine

func NormalizeCmdLine(s string) string

NormalizeCmdLine normalizes the command line by removing all ASCII whitespace and the null terminator at the beginning and end of the line.

func Validate

Validate validates the machinestate against image RIMs. If successful, returns the associated golden values.

Types

This section is empty.

Directories

Path Synopsis
Package data provides data related to confidential space image validation.
Package data provides data related to confidential space image validation.

Jump to