Documentation
¶
Overview ¶
Package image provides functions for validating confidential space images.
Index ¶
- func GetGoldenValues(ms *attestpb.MachineState, imageDb *rimpb.ImageDatabase) (*rimpb.ImageDatabase_ImageGoldenEntry, error)
- func KnownCertificate(known rimpb.ImageDatabase_CCKnownCertificates) *x509.Certificate
- func NormalizeCmdLine(s string) string
- func Validate(machineState *attestpb.MachineState, imageDb *rimpb.ImageDatabase) (*rimpb.ImageDatabase_ImageGoldenEntry, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetGoldenValues ¶
func GetGoldenValues(ms *attestpb.MachineState, imageDb *rimpb.ImageDatabase) (*rimpb.ImageDatabase_ImageGoldenEntry, error)
GetGoldenValues returns the golden values for the associated MachineState.
func KnownCertificate ¶
func KnownCertificate(known rimpb.ImageDatabase_CCKnownCertificates) *x509.Certificate
KnownCertificate returns the *x509.Certificate for a given rimpb.ImageDatabase_CCKnownCertificates enum value.
func NormalizeCmdLine ¶
NormalizeCmdLine normalizes the command line by removing all ASCII whitespace and the null terminator at the beginning and end of the line.
func Validate ¶
func Validate(machineState *attestpb.MachineState, imageDb *rimpb.ImageDatabase) (*rimpb.ImageDatabase_ImageGoldenEntry, error)
Validate validates the machinestate against image RIMs. If successful, returns the associated golden values.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.